sphinxcontrib_devhelp: Sphinx extension which outputs Devhelp documents
=======================================================================

Description
-----------

Sphinx extension which outputs Devhelp documents

License
-------

BSD
